from bunch import Bunch
from copy import deepcopy
from blockerbugs.util.bug_sync import BugSync
from mock import MagicMock
import datetime

basicbug = Bunch({'bug_id' : 123456,
                'weburl' : 'https://bugzilla.redhat.com/show_bug.cgi?id=123456',
                'component' : 'randomcomponent',
                'status' : 'NEW',
                'summary' : 'this is a test bug',
                'whiteboard' : '',
                'last_change_time' : datetime.datetime.utcnow()
                })

class TestSyncExtractInformation(object):

    def setup_method(self, method):
        self.testbug = deepcopy(basicbug)
        self.testsync = BugSync(None, MagicMock())

    def test_nth_isaccepted(self):
        self.testbug.whiteboard = 'AcceptedFreezeException'
        ref_isaccepted = True

        buginfo = self.testsync.extract_information(self.testbug, 'FreezeException')

        assert buginfo['accepted'] == ref_isaccepted

    def test_nth_isrejected(self):
        self.testbug.whiteboard = 'RejectedFreezeException'
        ref_isrejected = True

        buginfo = self.testsync.extract_information(self.testbug, 'FreezeException')

        assert buginfo['rejected'] == ref_isrejected

    def test_nth_isproposed(self):
        self.testbug.whiteboard = ''
        ref_isproposed = True

        buginfo = self.testsync.extract_information(self.testbug, 'FreezeException')

        assert buginfo['proposed'] == ref_isproposed

    def test_nth_isproposed_notrejected(self):
        self.testbug.whiteboard = ''
        ref_isrejected = False

        buginfo = self.testsync.extract_information(self.testbug, 'FreezeException')

        assert buginfo['rejected'] == ref_isrejected

    def test_nth_isproposed_notaccepted(self):
        self.testbug.whiteboard = ''
        ref_isaccepted = False

        buginfo = self.testsync.extract_information(self.testbug, 'FreezeException')

        assert buginfo['accepted'] == ref_isaccepted

    def test_blocker_isaccepted(self):
        self.testbug.whiteboard = 'AcceptedBlocker'
        ref_isaccepted = True

        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['accepted'] == ref_isaccepted

    def test_blocker_isaccepted_notproposed(self):
        self.testbug.whiteboard = 'AcceptedBlocker'

        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['proposed'] == False

    def test_bugid(self):
        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['bug_id'] == self.testbug['bug_id']

    def test_component(self):
        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['component'] == self.testbug['component']

    def test_title(self):
        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['summary'] == self.testbug['summary']

    def test_status(self):
        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['status'] == self.testbug['status']

    def test_url(self):
        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['url'] == self.testbug['weburl']

    def test_closed_inactive(self):
        self.testbug['status'] = 'CLOSED'
        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['active'] == False

    def test_notclosed_active(self):
        buginfo = self.testsync.extract_information(self.testbug, 'Blocker')

        assert buginfo['active'] == True
